@@ -5,8 +5,10 @@ import logging
 
 PROJECT_NAME = None
 
+__all__ = ["set_project_name", "add_log_file"]
 
-def set_project_name(project_name, force=False):
+
+def set_project_name(project_name: str, force: bool = False):
     global PROJECT_NAME
     if PROJECT_NAME:
         logging.warning("'PROJECT_NAME' has already been set")
@@ -20,7 +22,7 @@ def set_project_name(project_name, force=False):
         PROJECT_NAME = project_name
 
 
-def add_log_file(log_file, project_name=None):
+def add_log_file(log_file: str, project_name: str = None):
     if project_name:
         set_project_name(project_name)
     if not PROJECT_NAME:
@@ -32,7 +34,7 @@ def add_log_file(log_file, project_name=None):
         "default": PROJECT_NAME,
         "true": PROJECT_NAME,
         "false": None,
-    }.get[log_file.lower(), log_file]
+    }.get[str(log_file).lower(), log_file]
 
     if log_file:
         log_dir = appdirs.user_log_dir(PROJECT_NAME, "cleargrid")
